@@ -11,11 +11,13 @@ SLACK_ROOM_ID = environ.get("SLACK_ROOM_ID")
 class SlackTelemeter(logging.StreamHandler):
     __requires__ = ['SLACK_ROOM_ID']
 
-    def __init__(self, room_id):
+    def __init__(self, room_id=None):
         logging.StreamHandler.__init__(self)
         self.room_id = room_id
         if self.room_id is None:
             self.room_id = SLACK_ROOM_ID
+        if self.room_id is None:
+            raise TelemeterConfigException(f"SlackTelemeter requires {self.__requires__}")
         self.conn = HTTPSConnection(SLACK_HOST)
 
     def body(self, text):
